@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkMacOSXButton.c,v 1.2.2.2 2003/04/30 16:19:07 hobbs Exp $
+ * RCS: @(#) $Id: tkMacOSXButton.c,v 1.2.2.4 2003/10/10 20:20:47 hobbs Exp $
  */
 
 #include "tkButton.h"
@@ -417,15 +417,15 @@ TkpDisplayButton(
                     y += dpPtr->offset;
                 }
 		imageXOffset += x;
-		imageXOffset += y;
+		imageYOffset += y;
                 if (butPtr->image != NULL) {
                     if ((butPtr->selectImage != NULL) &&
                             (butPtr->flags & SELECTED)) {
                         Tk_RedrawImage(butPtr->selectImage, 0, 0, width,
-                                height, pixmap, x, y);
+                                height, pixmap, imageXOffset, imageYOffset);
                     } else {
                         Tk_RedrawImage(butPtr->image, 0, 0, width, height,
-                                pixmap, x, y);
+                                pixmap, imageXOffset, imageYOffset);
                     }
                 } else {
                     XSetClipOrigin(butPtr->display, dpPtr->gc, x, y);
@@ -1171,6 +1171,26 @@ SetupBevelButton(
                 "SetControlData BevelButtonGraphicAlign failed, %d\n", err );
     }
 
+    if (butPtr->compound != COMPOUND_NONE) {
+        ControlButtonTextPlacement thePlacement = \
+                kControlBevelButtonPlaceNormally;
+        if (butPtr->compound == COMPOUND_TOP) {
+            thePlacement = kControlBevelButtonPlaceBelowGraphic;
+        } else if (butPtr->compound == COMPOUND_BOTTOM) {
+            thePlacement = kControlBevelButtonPlaceAboveGraphic;
+        } else if (butPtr->compound == COMPOUND_LEFT) {
+            thePlacement = kControlBevelButtonPlaceToRightOfGraphic;
+        } else if (butPtr->compound == COMPOUND_RIGHT) {
+            thePlacement = kControlBevelButtonPlaceToLeftOfGraphic;
+        }
+        if ((err=SetControlData(controlHandle, kControlButtonPart,
+                kControlBevelButtonTextPlaceTag,
+                sizeof(ControlButtonTextPlacement),
+                (char *) &thePlacement)) != noErr ) {
+            fprintf(stderr,
+                    "SetControlData BevelButtonTextPlace failed, %d\n", err );
+        }
+    }
 }
 
 /*
